@@ -1,13 +1,14 @@
 #!/bin/sh -e
 
 # called by uscan with '--upstream-version' <version> <file>
-TAR=joda-convert_$2.orig.tar.gz
-DIR=joda-convert-$2
+VERSION=$2
+TAR=../joda-convert_$VERSION.orig.tar.gz
+DIR=joda-convert-$VERSION
 
 # clean up the upstream tarball
 tar -zxf $3
-tar -czf $TAR --exclude '*.jar' $DIR
-rm -rf $DIR $3
+GZIP=--best tar -zcvf $TAR --exclude '*.jar' $DIR
+rm -rf $DIR
 
 # move to directory 'tarballs'
 if [ -r .svn/deb-layout ]; then
